//
//  PRGrayscaleFilter.h
//  PRICE
//
//  Created by Riccardo Mottola on Mon Dec 23 2002.
//  Copyright (c) 2002-2007 Carduus. All rights reserved.
//
// This program is free software; you can redistribute it and/or modify it under the terms of the version 2 of the GNU General Public License as published by the Free Software Foundation.
// This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.


#import <AppKit/AppKit.h>
#import "PRImage.h"

#define METHOD_AVERAGE   1
#define METHOD_LUMINANCE 2

@interface PRGrayscaleFilter : NSObject {

}
- (PRImage *)filterImage:(PRImage *)srcImage :(int)method;

@end
